"""Add file_type_filter to watch_paths

Revision ID: f45fbcb8dbb4
Revises: 5186177178db
Create Date: 2026-02-08 11:18:43.382596

"""

from typing import Sequence, Union

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "f45fbcb8dbb4"
down_revision: Union[str, Sequence[str], None] = "5186177178db"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("watch_paths", sa.Column("file_type_filter", sa.String(), nullable=True))
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("watch_paths", "file_type_filter")
    # ### end Alembic commands ###
